@@ -9,13 +9,13 @@ import pytz
 from django.utils.timezone import now
 from eveuniverse.models import EveEntity, EveMoon, EveType
 
-from allianceauth.eveonline.models import (
-    EveAllianceInfo,
-    EveCharacter,
-    EveCorporationInfo,
+from allianceauth.eveonline.models import EveCorporationInfo
+from app_utils.testdata_factories import (
+    EveCharacterFactory,
+    EveCorporationInfoFactory,
+    UserMainFactory,
 )
-from allianceauth.tests.auth_utils import AuthUtils
-from app_utils.testing import add_character_to_user, create_user_from_evecharacter
+from app_utils.testing import create_user_from_evecharacter
 
 from ...app_settings import MOONMINING_VOLUME_PER_DAY
 from ...constants import EveTypeId
@@ -44,147 +44,17 @@ def datetime_to_ldap(my_dt: dt.datetime) -> int:
     ) * 10000000
 
 
-# django
+# Auth
 
 
-class UserFactory(factory.django.DjangoModelFactory):
-    class Meta:
-        model = "auth.User"
-        django_get_or_create = ("username",)
-        exclude = ("_generated_name",)
-
-    _generated_name = factory.Faker("name")
-    username = factory.LazyAttribute(lambda obj: obj._generated_name.replace(" ", "_"))
-    first_name = factory.LazyAttribute(lambda obj: obj._generated_name.split(" ")[0])
-    last_name = factory.LazyAttribute(lambda obj: obj._generated_name.split(" ")[1])
-    email = factory.LazyAttribute(
-        lambda obj: f"{obj.first_name.lower()}.{obj.last_name.lower()}@example.com"
-    )
-
-
-# auth
-
-
-class EveAllianceInfoFactory(factory.django.DjangoModelFactory):
-    class Meta:
-        model = EveAllianceInfo
-        django_get_or_create = ("alliance_id", "alliance_name")
-
-    alliance_id = factory.Sequence(lambda n: 99_000_001 + n)
-    alliance_name = factory.Faker("company")
-    alliance_ticker = factory.LazyAttribute(lambda obj: obj.alliance_name[:4].upper())
-    executor_corp_id = 0
-
-
-class EveCorporationInfoFactory(factory.django.DjangoModelFactory):
-    class Meta:
-        model = EveCorporationInfo
-        django_get_or_create = ("corporation_id", "corporation_name")
-
-    corporation_id = factory.Sequence(lambda n: 98_000_001 + n)
-    corporation_name = factory.Faker("company")
-    corporation_ticker = factory.LazyAttribute(
-        lambda obj: obj.corporation_name[:4].upper()
-    )
-    member_count = factory.fuzzy.FuzzyInteger(1000)
-
-    @factory.post_generation
-    def create_alliance(obj, create, extracted, **kwargs):
-        if not create or extracted is False:
-            return
-        obj.alliance = EveAllianceInfoFactory(executor_corp_id=obj.corporation_id)
-
-
-class EveCharacterFactory(factory.django.DjangoModelFactory):
-    class Meta:
-        model = EveCharacter
-        django_get_or_create = ("character_id", "character_name")
-        exclude = ("corporation",)
-
-    character_id = factory.Sequence(lambda n: 90_000_001 + n)
-    character_name = factory.Faker("name")
-    corporation = factory.SubFactory(EveCorporationInfoFactory)
-    corporation_id = factory.LazyAttribute(lambda obj: obj.corporation.corporation_id)
-    corporation_name = factory.LazyAttribute(
-        lambda obj: obj.corporation.corporation_name
-    )
-    corporation_ticker = factory.LazyAttribute(
-        lambda obj: obj.corporation.corporation_ticker
-    )
-
-    @factory.lazy_attribute
-    def alliance_id(self):
-        return (
-            self.corporation.alliance.alliance_id if self.corporation.alliance else None
-        )
-
-    @factory.lazy_attribute
-    def alliance_name(self):
-        return (
-            self.corporation.alliance.alliance_name if self.corporation.alliance else ""
-        )
-
-    @factory.lazy_attribute
-    def alliance_ticker(self):
-        return (
-            self.corporation.alliance.alliance_ticker
-            if self.corporation.alliance
-            else ""
-        )
-
-
-class UserMainFactory(UserFactory):
-    @factory.post_generation
-    def main_character(obj, create, extracted, **kwargs):
-        if not create:
-            return
-        if "character" in kwargs:
-            character = kwargs["character"]
-        else:
-            character_name = f"{obj.first_name} {obj.last_name}"
-            character = EveCharacterFactory(character_name=character_name)
-
-        scopes = kwargs["scopes"] if "scopes" in kwargs else None
-        add_character_to_user(
-            user=obj, character=character, is_main=True, scopes=scopes
-        )
-
-
-class DefaultUserMainFactory(UserMainFactory):
+class DefaultOwnerUserMainFactory(UserMainFactory):
     main_character__scopes = Owner.esi_scopes()
-
-    @factory.post_generation
-    def permissions(obj, create, extracted, **kwargs):
-        """Set default permissions. Overwrite with `permissions=["app.perm1"]`."""
-        if not create:
-            return
-        permissions = (
-            extracted
-            if extracted
-            else [
-                "moonmining.basic_access",
-                "moonmining.upload_moon_scan",
-                "moonmining.extractions_access",
-                "moonmining.add_refinery_owner",
-            ]
-        )
-        for permission_name in permissions:
-            AuthUtils.add_permission_to_user_by_name(permission_name, obj)
-
-    @classmethod
-    def _after_postgeneration(cls, obj, create, results=None):
-        """Reset permission cache to force an update."""
-        super()._after_postgeneration(obj, create, results)
-        if hasattr(obj, "_perm_cache"):
-            del obj._perm_cache
-        if hasattr(obj, "_user_perm_cache"):
-            del obj._user_perm_cache
-
-
-class DefaultOwnerUserMainFactory(DefaultUserMainFactory):
-    # main_character__character = factory.SubFactory(
-    #     EveCharacterFactory, character_id=1001, character_name="Bruce Wayne"
-    # )
+    permissions__ = [
+        "moonmining.basic_access",
+        "moonmining.upload_moon_scan",
+        "moonmining.extractions_access",
+        "moonmining.add_refinery_owner",
+    ]
 
     @factory.lazy_attribute
     def main_character__character(self):
